@@ -1373,6 +1373,8 @@ gboolean irreco_show_remote_download_dlg(IrrecoData *irreco_data,
 			GString *bg_image = g_string_new("");
 			GString *notification = g_string_new("");
 			IrrecoDirForeachData dir_data;
+			GString *tmp;
+			GString *tmp2;
 
 			IRRECO_DEBUG("IRRECO_REMOTE_DOWNLOAD\n");
 			webdb_cache = irreco_data_get_webdb_cache(
@@ -1557,17 +1559,27 @@ gboolean irreco_show_remote_download_dlg(IrrecoData *irreco_data,
 			if (bg_image->len < 10) {
 				goto no_bg;
 			}
-			/* Find bg_image from mmc1 */
-			bg_image = g_string_erase(bg_image, 10, 1);
-			bg_image = g_string_insert_c(bg_image, 10, '1');
 
-			/* Use /home/user/MyDocs if bg_image does not exists */
-			if (!irreco_file_exists(bg_image->str)) {
-				/*bg_image = g_string_erase(bg_image, 10, 1);
-				bg_image = g_string_insert_c(bg_image, 10, '2');*/
-				bg_image = g_string_assign(bg_image, "/home/user/MyDocs");
+			tmp = g_string_new(bg_image->str);
+			tmp = g_string_erase(tmp, 6, -1);
+			tmp2 = g_string_new("/media");
+
+
+			IRRECO_PRINTF("VERTAILU");
+			IRRECO_PRINTF(tmp->str);
+
+			if(g_string_equal(tmp, tmp2))
+			{
+				bg_image = g_string_erase(bg_image, 0, 11);
+				bg_image = g_string_prepend(bg_image, "/home/user/MyDocs");
+
+				IRRECO_PRINTF(bg_image->str);
 			}
 
+			IRRECO_PAUSE
+			g_string_free(tmp, TRUE);
+			g_string_free(tmp2, TRUE);
+
 			/* Set bg-image to layout */
 			irreco_button_layout_set_bg_image(layout,
 							  bg_image->str);
