@@ -249,8 +249,8 @@ void irreco_window_edit_device_help(IrrecoWindowEdit * edit_window)
 		}
 	IRRECO_BACKEND_MANAGER_FOREACH_END
 
-	irreco_info_dlg(irreco_window_get_gtk_window(edit_window->window),
-			_(IRRECO_NO_DEVICE_HELP));
+	/*irreco_info_dlg(irreco_window_get_gtk_window(edit_window->window),
+			_(IRRECO_NO_DEVICE_HELP));*/
 	IRRECO_RETURN
 }
 
